<?php

/**
 * @file
 * Support for processing Metis fields in Migrate.
 */

/**
 * Implements hook_migrate_api().
 */
function metis_migrate_api() {
  return array(
    'api' => 2,
    'field handlers' => ['MigrateMetisFieldHandler'],
  );
}

/**
 * Extended class for handling metis fields.
 */
class MigrateMetisFieldHandler extends MigrateDefaultFieldHandler {

  /**
   * Constructor.
   */
  public function __construct() {
    $this->registerTypes(['metis']);
  }

  /**
   * Implements MigrateFieldHandler::prepare().
   */
  public function prepare($entity, array $field_info, array $instance, array $values) {
    // Let the derived class skip empty values.
    $values = array_filter($values, [$this, 'notNull']);
    return parent::prepare($entity, $field_info, $instance, $values);
  }

  /**
   * Returns TRUE only for values which are not NULL.
   *
   * @param $value
   *
   * @return bool
   */
  protected function notNull($value) {
    return !is_null($value);
  }

  /**
   * Overrides MigrateDefaultFieldHandler::handlesType().
   *
   * The implementation of MigrateDefaultFieldHandler handles any field type,
   * we must retrict our class to handle metis fields only.
   */
  public function handlesType($type) {
    return isset($this->typesHandled[strtolower($type)]);
  }

}
